@@ -28,6 +28,7 @@ from PyFstat_example_make_data_for_search_on_1_glitch import (
 import pyfstat
 
 label = "PyFstat_example_glitch_robust_directed_grid_search_on_1_glitch"
+logger = pyfstat.set_up_logger(label=label, outdir=outdir)
 
 Nstar = 1000
 F0_width = np.sqrt(Nstar) * np.sqrt(12) / (np.pi * duration)
@@ -71,7 +72,7 @@ delta_F0s_vals = np.unique(search.data["delta_F0"]) - delta_F0
 tglitch_vals = np.unique(search.data["tglitch"])
 tglitch_vals_days = (tglitch_vals - tstart) / 86400.0 - dtglitch / 86400.0
 
-print("Making gridcorner plot...")
+logger.info("Making gridcorner plot...")
 twoF = search.data["twoF"].reshape(
     (len(F0_vals), len(F1_vals), len(delta_F0s_vals), len(tglitch_vals))
 )
@@ -97,6 +98,6 @@ fig, axes = pyfstat.gridcorner(
 fig.savefig("{}/{}_projection_matrix.png".format(outdir, label), bbox_inches="tight")
 
 
-print(("Prior widths =", F0_width, F1_width))
-print(("Actual run time = {}".format(dT)))
-print(("Actual number of grid points = {}".format(search.data.shape[0])))
+logger.info(f"Prior widths = {F0_width}, {F1_width}")
+logger.info(f"Actual run time = {dT} s")
+logger.info(f"Actual number of grid points = {search.data.shape[0]}")
