@@ -1,7 +1,16 @@
-from pyfstat import Writer, GlitchWriter
-import numpy as np
+"""
+Glitch examples: Make data
+==========================
+
+Generate the data to run examples on glitch-robust searches.
+"""
+
 import os
 
+import numpy as np
+
+from pyfstat import GlitchWriter, Writer
+
 outdir = os.path.join("PyFstat_example_data", "PyFstat_example_glitch_robust_search")
 
 # First, we generate data with a reasonably strong smooth signal
