@@ -11,10 +11,11 @@ import os
 import numpy as np
 
 import pyfstat
-from pyfstat.helper_functions import get_predict_fstat_parameters_from_dict
+from pyfstat.utils import get_predict_fstat_parameters_from_dict
 
 label = "PyFstat_example_twoF_cumulative"
 outdir = os.path.join("PyFstat_example_data", label)
+logger = pyfstat.set_up_logger(label=label, outdir=outdir)
 
 # Properties of the GW data
 gw_data = {
@@ -66,7 +67,7 @@ data.make_data()
 
 # The predicted twoF, given by lalapps_predictFstat can be accessed by
 twoF = data.predict_fstat()
-print("Predicted twoF value: {}\n".format(twoF))
+logger.info("Predicted twoF value: {}\n".format(twoF))
 
 # Create a search object for each of the possible SFT combinations
 # (H1 only, L1 only, H1 + L1).
