@@ -16,6 +16,8 @@ import os
 import pyfstat
 
 outdir = os.path.join("PyFstat_example_data", "PyFstat_example_short_transient_search")
+logger = pyfstat.set_up_logger(outdir=outdir, label="short_transient_search")
+
 
 F0 = 30.0
 F1 = -1e-10
@@ -64,4 +66,4 @@ if __name__ == "__main__":
         Band=0.1,
     )
     transient.make_data()
-    print("Predicted 2F from injection Writer:", transient.predict_fstat())
+    logger.info(f"Predicted 2F from injection Writer: {transient.predict_fstat()}")
