@@ -16,24 +16,16 @@ import numpy as np
 import scipy.optimize
 import scipy.special
 
-import pyfstat.helper_functions as helper_functions
 import pyfstat.tcw_fstat_map_funcs as tcw
+import pyfstat.utils as utils
 
-# workaround for matplotlib on X-less remote logins
-if "DISPLAY" in os.environ:
-    import matplotlib.pyplot as plt
-else:
-    logging.info(
-        'No $DISPLAY environment variable found, so importing \
-                  matplotlib.pyplot with non-interactive "Agg" backend.'
-    )
-    import matplotlib
+from ._version import get_versions
 
-    matplotlib.use("Agg")
-    import matplotlib.pyplot as plt
+plt = utils.safe_X_less_plt()
+
+
+logger = logging.getLogger(__name__)
 
-helper_functions.set_up_matplotlib_defaults()
-args = helper_functions.set_up_command_line_arguments()
 detector_colors = {"h1": "C0", "l1": "C1"}
 
 
@@ -46,26 +38,10 @@ class BaseSearchClass:
     """
 
     def __new__(cls, *args, **kwargs):
-        logging.info(f"Creating {cls.__name__} object...")
+        logger.info(f"Creating {cls.__name__} object...")
         instance = super().__new__(cls)
         return instance
 
-    def _add_log_file(self, header=None):
-        """Log output to a file, requires class to have outdir and label"""
-        header = [] if header is None else header
-        logfilename = os.path.join(self.outdir, self.label + ".log")
-        with open(logfilename, "w") as fp:
-            for hline in header:
-                fp.write("# {:s}\n".format(hline))
-        fh = logging.FileHandler(logfilename)
-        fh.setLevel(logging.INFO)
-        fh.setFormatter(
-            logging.Formatter(
-                "%(asctime)s %(levelname)-8s: %(message)s", datefmt="%y-%m-%d %H:%M"
-            )
-        )
-        logging.getLogger().addHandler(fh)
-
     def _get_list_of_matching_sfts(self):
         """Returns a list of sfts matching the attribute sftfilepattern"""
         sftfilepatternlist = np.atleast_1d(self.sftfilepattern.split(";"))
@@ -80,7 +56,7 @@ class BaseSearchClass:
         """Set the ephemeris files to use for the Earth and Sun.
 
         NOTE: If not given explicit arguments,
-        default values from helper_functions.get_ephemeris_files()
+        default values from utils.get_ephemeris_files()
         are used.
 
         Parameters
@@ -89,7 +65,7 @@ class BaseSearchClass:
             Paths of the two files containing positions of Earth and Sun,
             respectively at evenly spaced times, as passed to CreateFstatInput
         """
-        earth_ephem_default, sun_ephem_default = helper_functions.get_ephemeris_files()
+        earth_ephem_default, sun_ephem_default = utils.get_ephemeris_files()
         self.earth_ephem = earth_ephem or earth_ephem_default
         self.sun_ephem = sun_ephem or sun_ephem_default
 
@@ -140,7 +116,7 @@ class BaseSearchClass:
             "date: {}".format(str(datetime.now())),
             "user: {}".format(getpass.getuser()),
             "hostname: {}".format(socket.gethostname()),
-            "PyFstat: {}".format(helper_functions.get_version_string()),
+            "PyFstat: {}".format(get_versions()["version"]),
         ]
         lalVCSinfo = lal.VCSInfoString(lalpulsar.PulsarVCSInfoList, 0, "")
         header += filter(None, lalVCSinfo.split("\n"))
@@ -172,7 +148,7 @@ class BaseSearchClass:
             A dictionary of the parsed `key=val` pairs.
 
         """
-        params_dict = helper_functions.read_par(
+        params_dict = utils.read_par(
             filename=filename,
             label=label or getattr(self, "label", None),
             outdir=outdir or getattr(self, "outdir", None),
@@ -267,7 +243,7 @@ class ComputeFstat(BaseSearchClass):
     or manually call the `search.finalizer_()` method where needed.
     """
 
-    @helper_functions.initializer
+    @utils.initializer
     def __init__(
         self,
         tref,
@@ -425,11 +401,11 @@ class ComputeFstat(BaseSearchClass):
         earth_ephem: str
             Earth ephemeris file path.
             If None, will check standard sources as per
-            helper_functions.get_ephemeris_files().
+            utils.get_ephemeris_files().
         sun_ephem: str
             Sun ephemeris file path.
             If None, will check standard sources as per
-            helper_functions.get_ephemeris_files().
+            utils.get_ephemeris_files().
         allowedMismatchFromSFTLength: float
             Maximum allowed mismatch from SFTs being too long
             [Default: what's hardcoded in XLALFstatMaximumSFTLength]
@@ -456,30 +432,29 @@ class ComputeFstat(BaseSearchClass):
         using context management or calling the `.finalizer_()` method.
         """
         if "cuda" in self.tCWFstatMapVersion:
-            logging.debug(
+            logger.debug(
                 f"Setting up GPU context finalizer for {self.tCWFstatMapVersion} transient maps."
             )
             self._finalizer = finalize(self, self._finalize_gpu_context)
-        else:
-            self._finalizer = None
 
     def _finalize_gpu_context(self):
         """Clean up at the end of context manager style usage."""
-        logging.debug("Leaving the ComputeFStat context...")
+        logger.debug("Leaving the ComputeFStat context...")
         if hasattr(self, "gpu_context") and self.gpu_context:
-            logging.debug("Detaching GPU context...")
+            logger.debug("Detaching GPU context...")
             # this is needed because we use pyCuda without autoinit
             self.gpu_context.detach()
 
     def __enter__(self):
         """Enables context manager style calling."""
-        logging.debug("Entering the ComputeFstat context...")
+        logger.debug("Entering the ComputeFstat context...")
         return self
 
     def __exit__(self, *args, **kwargs):
         """Clean up at the end of context manager style usage."""
-        logging.debug("Leaving the ComputeFStat context...")
-        self._finalizer()
+        logger.debug("Leaving the ComputeFStat context...")
+        if "cuda" in self.tCWFstatMapVersion:
+            self._finalizer()
 
     def _get_SFTCatalog(self):
         """Load the SFTCatalog
@@ -488,10 +463,10 @@ class ComputeFstat(BaseSearchClass):
         create data on the fly.
         """
         if hasattr(self, "SFTCatalog"):
-            logging.info("Already have SFTCatalog.")
+            logger.info("Already have SFTCatalog.")
             return
         if self.sftfilepattern is None:
-            logging.info("No sftfilepattern given, making fake SFTCatalog.")
+            logger.info("No sftfilepattern given, making fake SFTCatalog.")
             for k in ["minStartTime", "maxStartTime", "detectors"]:
                 if getattr(self, k) is None:
                     raise ValueError(
@@ -522,12 +497,12 @@ class ComputeFstat(BaseSearchClass):
             self.SFTCatalog = SFTCatalog
             return
 
-        logging.info("Initialising SFTCatalog from sftfilepattern.")
+        logger.info("Initialising SFTCatalog from sftfilepattern.")
         constraints = lalpulsar.SFTConstraints()
         constr_str = []
         if self.detectors:
             if "," in self.detectors:
-                logging.warning(
+                logger.warning(
                     "Multiple-detector constraints not available,"
                     " using all available data."
                 )
@@ -540,14 +515,14 @@ class ComputeFstat(BaseSearchClass):
         if self.maxStartTime:
             constraints.maxStartTime = lal.LIGOTimeGPS(self.maxStartTime)
             constr_str.append("maxStartTime={}".format(self.maxStartTime))
-        logging.info(
+        logger.info(
             "Loading data matching SFT file name pattern '{}'"
             " with constraints {}.".format(self.sftfilepattern, ", ".join(constr_str))
         )
         self.SFTCatalog = lalpulsar.SFTdataFind(self.sftfilepattern, constraints)
         Tsft_from_catalog = int(1.0 / self.SFTCatalog.data[0].header.deltaF)
         if Tsft_from_catalog != self.Tsft:
-            logging.info(
+            logger.info(
                 "Overwriting pre-set Tsft={:d} with {:d} obtained from SFTs.".format(
                     self.Tsft, Tsft_from_catalog
                 )
@@ -561,9 +536,9 @@ class ComputeFstat(BaseSearchClass):
         if len(SFT_timestamps) == 0:
             raise ValueError("Failed to load any data")
 
-        dtstr1 = helper_functions.gps_to_datestr_utc(int(SFT_timestamps[0]))
-        dtstr2 = helper_functions.gps_to_datestr_utc(int(SFT_timestamps[-1]))
-        logging.info(
+        dtstr1 = utils.gps_to_datestr_utc(int(SFT_timestamps[0]))
+        dtstr2 = utils.gps_to_datestr_utc(int(SFT_timestamps[-1]))
+        logger.info(
             f"Data contains SFT timestamps from {SFT_timestamps[0]} ({dtstr1})"
             f" to (including) {SFT_timestamps[-1]} ({dtstr2})."
         )
@@ -579,7 +554,7 @@ class ComputeFstat(BaseSearchClass):
         self.numDetectors = len(self.detector_names)
         if self.numDetectors == 0:
             raise ValueError("No data loaded.")
-        logging.info(
+        logger.info(
             "Loaded {} SFTs from {} detectors: {}".format(
                 len(SFT_timestamps), self.numDetectors, self.detector_names
             )
@@ -606,10 +581,10 @@ class ComputeFstat(BaseSearchClass):
             if getattr(self, "BtSG", False):
                 raise ValueError("Please choose only one of [BSGL,BtSG].")
 
-        logging.info("Initialising ephems")
+        logger.info("Initialising ephems")
         ephems = lalpulsar.InitBarycenter(self.earth_ephem, self.sun_ephem)
 
-        logging.info("Initialising Fstat arguments")
+        logger.info("Initialising Fstat arguments")
         dFreq = 0
         self.whatToCompute = lalpulsar.FSTATQ_2F
         if self.transientWindowType or self.computeAtoms:
@@ -617,7 +592,7 @@ class ComputeFstat(BaseSearchClass):
 
         FstatOAs = lalpulsar.FstatOptionalArgs()
         if self.SSBprec:
-            logging.info("Using SSBprec={}".format(self.SSBprec))
+            logger.info("Using SSBprec={}".format(self.SSBprec))
             FstatOAs.SSBprec = self.SSBprec
         else:
             FstatOAs.SSBprec = lalpulsar.FstatOptionalArgsDefaults.SSBprec
@@ -633,7 +608,7 @@ class ComputeFstat(BaseSearchClass):
             FstatOAs.assumeSqrtSX = lalpulsar.FstatOptionalArgsDefaults.assumeSqrtSX
         else:
             mnf = lalpulsar.MultiNoiseFloor()
-            assumeSqrtSX = helper_functions.parse_list_of_numbers(self.assumeSqrtSX)
+            assumeSqrtSX = utils.parse_list_of_numbers(self.assumeSqrtSX)
             mnf.sqrtSn[: len(assumeSqrtSX)] = assumeSqrtSX
             mnf.length = len(assumeSqrtSX)
             FstatOAs.assumeSqrtSX = mnf
@@ -643,7 +618,7 @@ class ComputeFstat(BaseSearchClass):
             FstatOAs.allowedMismatchFromSFTLength = self.allowedMismatchFromSFTLength
 
         if hasattr(self, "injectSources") and type(self.injectSources) == dict:
-            logging.info("Injecting source with params: {}".format(self.injectSources))
+            logger.info("Injecting source with params: {}".format(self.injectSources))
             PPV = lalpulsar.CreatePulsarParamsVector(1)
             PP = PPV.data[0]
             h0 = self.injectSources["h0"]
@@ -671,7 +646,7 @@ class ComputeFstat(BaseSearchClass):
                 PP.Transient.type = lalpulsar.TRANSIENT_NONE
             FstatOAs.injectSources = PPV
         elif hasattr(self, "injectSources") and type(self.injectSources) == str:
-            logging.info(
+            logger.info(
                 "Injecting source from param file: {}".format(self.injectSources)
             )
             PPV = lalpulsar.PulsarParamsFromFile(self.injectSources, self.tref)
@@ -679,9 +654,7 @@ class ComputeFstat(BaseSearchClass):
         else:
             FstatOAs.injectSources = lalpulsar.FstatOptionalArgsDefaults.injectSources
         if hasattr(self, "injectSqrtSX") and self.injectSqrtSX is not None:
-            self.injectSqrtSX = helper_functions.parse_list_of_numbers(
-                self.injectSqrtSX
-            )
+            self.injectSqrtSX = utils.parse_list_of_numbers(self.injectSqrtSX)
             if len(self.injectSqrtSX) != len(self.detector_names):
                 raise ValueError(
                     "injectSqrtSX must be of same length as detector_names ({}!={})".format(
@@ -704,7 +677,7 @@ class ComputeFstat(BaseSearchClass):
         )
         self._set_min_max_cover_freqs()
 
-        logging.info("Initialising FstatInput")
+        logger.info("Initialising FstatInput")
         self.FstatInput = lalpulsar.CreateFstatInput(
             self.SFTCatalog,
             self.minCoverFreq,
@@ -714,7 +687,7 @@ class ComputeFstat(BaseSearchClass):
             FstatOAs,
         )
 
-        logging.info("Initialising PulsarDoplerParams")
+        logger.info("Initialising PulsarDoplerParams")
         PulsarDopplerParams = lalpulsar.PulsarDopplerParams()
         PulsarDopplerParams.refTime = self.tref
         PulsarDopplerParams.Alpha = 1
@@ -722,7 +695,7 @@ class ComputeFstat(BaseSearchClass):
         PulsarDopplerParams.fkdot = np.zeros(lalpulsar.PULSAR_MAX_SPINS)
         self.PulsarDopplerParams = PulsarDopplerParams
 
-        logging.info("Initialising FstatResults")
+        logger.info("Initialising FstatResults")
         self.FstatResults = lalpulsar.FstatResults()
 
         # always initialise the twoFX array,
@@ -734,7 +707,7 @@ class ComputeFstat(BaseSearchClass):
             self.whatToCompute += lalpulsar.FSTATQ_2F_PER_DET
 
         if self.BSGL:
-            logging.info("Initialising BSGL")
+            logger.info("Initialising BSGL")
             self.log10BSGL = np.nan
             # Tuning parameters - to be reviewed
             # We use a fixed Fstar0 for coherent searches,
@@ -749,7 +722,7 @@ class ComputeFstat(BaseSearchClass):
                     raise ValueError("Max Fstar0 exceeded")
             else:
                 self.Fstar0 = 15.0
-            logging.info("Using Fstar0 of {:1.2f}".format(self.Fstar0))
+            logger.info("Using Fstar0 of {:1.2f}".format(self.Fstar0))
             # assume uniform per-detector prior line-vs-Gaussian odds
             self.oLGX = np.zeros(lalpulsar.PULSAR_MAX_DETECTORS)
             self.oLGX[: self.numDetectors] = 1.0 / self.numDetectors
@@ -762,7 +735,7 @@ class ComputeFstat(BaseSearchClass):
             )
 
         if self.transientWindowType:
-            logging.info("Initialising transient parameters")
+            logger.info("Initialising transient parameters")
             self.maxTwoF = 0
             if getattr(self, "BtSG", False):
                 self.lnBtSG = np.nan
@@ -797,7 +770,7 @@ class ComputeFstat(BaseSearchClass):
                     self.windowRange.t0Band = 0
                 else:
                     if not isinstance(self.t0Band, int):
-                        logging.warn(
+                        logger.warning(
                             "Casting non-integer t0Band={} to int...".format(
                                 self.t0Band
                             )
@@ -810,7 +783,7 @@ class ComputeFstat(BaseSearchClass):
                     self.windowRange.tauBand = 0
                 else:
                     if not isinstance(self.tauBand, int):
-                        logging.warn(
+                        logger.warning(
                             "Casting non-integer tauBand={} to int...".format(
                                 self.tauBand
                             )
@@ -823,7 +796,7 @@ class ComputeFstat(BaseSearchClass):
                         self.windowRange.tau = int(2 * self.Tsft)
                     else:
                         if not isinstance(self.tauMin, int):
-                            logging.warn(
+                            logger.warning(
                                 "Casting non-integer tauMin={} to int...".format(
                                     self.tauMin
                                 )
@@ -831,7 +804,7 @@ class ComputeFstat(BaseSearchClass):
                             self.tauMin = int(self.tauMin)
                         self.windowRange.tau = self.tauMin
 
-            logging.info("Initialising transient FstatMap features...")
+            logger.info("Initialising transient FstatMap features...")
             (
                 self.tCWFstatMapFeatures,
                 self.gpu_context,
@@ -860,7 +833,7 @@ class ComputeFstat(BaseSearchClass):
                 "Please use either search_ranges or both of [minCoverFreq,maxCoverFreq]."
             )
         elif self.minCoverFreq is None or self.maxCoverFreq is None:
-            logging.info(
+            logger.info(
                 "[minCoverFreq,maxCoverFreq] not provided, trying to estimate"
                 " from search ranges."
             )
@@ -875,7 +848,7 @@ class ComputeFstat(BaseSearchClass):
                     " or set both to None (automated estimation)."
                 )
             if self.minCoverFreq < 0.0:
-                logging.info(
+                logger.info(
                     "minCoverFreq={:f} provided, using as offset from min(SFTs).".format(
                         self.minCoverFreq
                     )
@@ -883,7 +856,7 @@ class ComputeFstat(BaseSearchClass):
                 # to set *above* min, since minCoverFreq is negative: subtract it
                 self.minCoverFreq = minFreq_SFTs - self.minCoverFreq
             if self.maxCoverFreq < 0.0:
-                logging.info(
+                logger.info(
                     "maxCoverFreq={:f} provided, using as offset from max(SFTs).".format(
                         self.maxCoverFreq
                     )
@@ -899,7 +872,7 @@ class ComputeFstat(BaseSearchClass):
                     self.minCoverFreq, self.maxCoverFreq, minFreq_SFTs, maxFreq_SFTs
                 )
             )
-        logging.info(
+        logger.info(
             "Using minCoverFreq={} and maxCoverFreq={}.".format(
                 self.minCoverFreq, self.maxCoverFreq
             )
@@ -1030,7 +1003,7 @@ class ComputeFstat(BaseSearchClass):
             maxOrbitEcc = 0.0
         # finally call the wrapped lalpulsar estimation function with the
         # extended PulsarSpinRange and optional binary parameters
-        self.minCoverFreq, self.maxCoverFreq = helper_functions.get_covering_band(
+        self.minCoverFreq, self.maxCoverFreq = utils.get_covering_band(
             tref=self.tref,
             tstart=self.minStartTime,
             tend=self.maxStartTime,
@@ -1344,19 +1317,10 @@ class ComputeFstat(BaseSearchClass):
         # and return the maximum of that?
         idx_maxTwoF = self.FstatMap.get_maxF_idx()
         for X in range(self.FstatResults.numDetectors):
-            # For each detector, we need to build a MultiFstatAtomVector
-            # because that's what the Fstat map function expects.
-            singleIFOmultiFatoms = lalpulsar.CreateMultiFstatAtomVector(1)
-            # The first [0] index on the multiFatoms here is over frequency bins;
+            # The [0] index on the multiFatoms here is over frequency bins;
             # we always operate on a single bin.
-            singleIFOmultiFatoms.data[0] = lalpulsar.CreateFstatAtomVector(
-                self.FstatResults.multiFatoms[0].data[X].length
-            )
-            singleIFOmultiFatoms.data[0].TAtom = (
-                self.FstatResults.multiFatoms[0].data[X].TAtom
-            )
-            singleIFOmultiFatoms.data[0].data = (
-                self.FstatResults.multiFatoms[0].data[X].data
+            singleIFOmultiFatoms = utils.extract_singleIFOmultiFatoms_from_multiAtoms(
+                self.FstatResults.multiFatoms[0], X
             )
             FXstatMap, timingFXstatMap = tcw.call_compute_transient_fstat_map(
                 self.tCWFstatMapVersion,
@@ -1511,7 +1475,7 @@ class ComputeFstat(BaseSearchClass):
         num_segments: int
             Number of segments to split [tstart,tend] into.
         predict_fstat_kwargs:
-            Other kwargs to be passed to helper_functions.predict_fstat().
+            Other kwargs to be passed to utils.predict_fstat().
 
         Returns
         -------
@@ -1529,7 +1493,7 @@ class ComputeFstat(BaseSearchClass):
             tstart, tend, num_segments
         )
         out = [
-            helper_functions.predict_fstat(
+            utils.predict_fstat(
                 minStartTime=tstart,
                 duration=duration,
                 sftfilepattern=self.sftfilepattern,
@@ -1624,7 +1588,7 @@ class ComputeFstat(BaseSearchClass):
         if custom_ax_kwargs is not None:
             for kwarg in "xlabel", "ylabel":
                 if kwarg in custom_ax_kwargs:
-                    logging.warning(
+                    logger.warning(
                         f"Be careful, overwriting {kwarg} {axis_kwargs[kwarg]}"
                         " with {custom_ax_kwargs[kwarg]}: Check out the units!"
                     )
@@ -1685,7 +1649,7 @@ class ComputeFstat(BaseSearchClass):
             plt.close()
         return ax
 
-    def write_atoms_to_file(self, fnamebase=""):
+    def write_atoms_to_file(self, fnamebase="", comments="%%"):
         """Save F-statistic atoms (time-dependent quantities) for a given parameter-space point.
 
         Parameters
@@ -1695,6 +1659,13 @@ class ComputeFstat(BaseSearchClass):
             `{fnamebase}_Fstatatoms_{dopplerName}.dat`
             where `dopplerName` is a canonical lalpulsar formatting of the
             'Doppler' parameter space point (frequency-evolution parameters).
+        comments: str
+            Comments marker character(s) to be prepended to header lines.
+            Note that the column headers line
+            (last line of the header before the atoms data)
+            is printed by lalpulsar, with `%%` as comments marker,
+            so (different from most other PyFstat functions)
+            the default here is `%%` too.
         """
         multiFatoms = getattr(self.FstatResults, "multiFatoms", None)
         if multiFatoms and multiFatoms[0]:
@@ -1703,7 +1674,7 @@ class ComputeFstat(BaseSearchClass):
             fnameAtoms = f"{fnamebase}_Fstatatoms_{dopplerName}.dat"
             fo = lal.FileOpen(fnameAtoms, "w")
             for hline in self.output_file_header:
-                lal.FilePuts(f"# {hline}\n", fo)
+                lal.FilePuts(f"{comments} {hline}\n", fo)
             lalpulsar.write_MultiFstatAtoms_to_fp(fo, multiFatoms[0])
             del fo  # instead of lal.FileClose() which is not SWIG-exported
         else:
@@ -1730,7 +1701,7 @@ class SemiCoherentSearch(ComputeFstat):
     per-segment F-stats, and these are summed to get the semi-coherent result.
     """
 
-    @helper_functions.initializer
+    @utils.initializer
     def __init__(
         self,
         label,
@@ -1830,7 +1801,7 @@ class SemiCoherentSearch(ComputeFstat):
 
         Each segment is required to be at least two SFTs long.f
         """
-        logging.info(
+        logger.info(
             (
                 "Initialising semicoherent parameters from"
                 " minStartTime={:d} to maxStartTime={:d} in {:d} segments..."
@@ -1840,12 +1811,12 @@ class SemiCoherentSearch(ComputeFstat):
             self.minStartTime, self.maxStartTime, self.nsegs + 1
         )
         self.Tcoh = self.tboundaries[1] - self.tboundaries[0]
-        logging.info(
+        logger.info(
             ("Obtained {:d} segments of length Tcoh={:f}s (={:f}d).").format(
                 self.nsegs, self.Tcoh, self.Tcoh / 86400.0
             )
         )
-        logging.debug("Segment boundaries: {}".format(self.tboundaries))
+        logger.debug("Segment boundaries: {}".format(self.tboundaries))
         if self.Tcoh < 2 * self.Tsft:
             raise RuntimeError(
                 "Per-segment coherent time {} may not be < Tsft={}"
@@ -1979,7 +1950,7 @@ class SemiCoherentSearch(ComputeFstat):
         self.twoF = twoF_per_segment.sum()
 
         if np.isnan(self.twoF):
-            logging.debug(
+            logger.debug(
                 "NaNs in per-segment 2F treated as zero"
                 " and semi-coherent 2F re-computed."
             )
@@ -2014,19 +1985,10 @@ class SemiCoherentSearch(ComputeFstat):
                 "This function is available only if singleFstats or BSGL options were set."
             )
         for X in range(self.FstatResults.numDetectors):
-            # For each detector, we need to build a MultiFstatAtomVector
-            # because that's what the Fstat map function expects.
-            singleIFOmultiFatoms = lalpulsar.CreateMultiFstatAtomVector(1)
-            # The first [0] index on the multiFatoms here is over frequency bins;
+            # The [0] index on the multiFatoms here is over frequency bins;
             # we always operate on a single bin.
-            singleIFOmultiFatoms.data[0] = lalpulsar.CreateFstatAtomVector(
-                self.FstatResults.multiFatoms[0].data[X].length
-            )
-            singleIFOmultiFatoms.data[0].TAtom = (
-                self.FstatResults.multiFatoms[0].data[X].TAtom
-            )
-            singleIFOmultiFatoms.data[0].data = (
-                self.FstatResults.multiFatoms[0].data[X].data
+            singleIFOmultiFatoms = utils.extract_singleIFOmultiFatoms_from_multiAtoms(
+                self.FstatResults.multiFatoms[0], X
             )
             FXstatMap = lalpulsar.ComputeTransientFstatMap(
                 multiFstatAtoms=singleIFOmultiFatoms,
@@ -2036,7 +1998,7 @@ class SemiCoherentSearch(ComputeFstat):
             twoFX_per_segment = 2 * FXstatMap.F_mn.data[:, 0]
             self.twoFX[X] = twoFX_per_segment.sum()
             if np.isnan(self.twoFX[X]):
-                logging.debug(
+                logger.debug(
                     "NaNs in per-segment per-detector 2F treated as zero"
                     " and sum re-computed."
                 )
@@ -2064,7 +2026,7 @@ class SemiCoherentSearch(ComputeFstat):
         """
         self.log10BSGL = lalpulsar.ComputeBSGL(self.twoF, self.twoFX, self.BSGLSetup)
         if np.isnan(self.log10BSGL):
-            logging.debug("NaNs in semi-coherent log10BSGL treated as zero")
+            logger.debug("NaNs in semi-coherent log10BSGL treated as zero")
             self.log10BSGL = 0.0
         return self.log10BSGL
 
@@ -2198,7 +2160,7 @@ class SemiCoherentGlitchSearch(SearchForSignalWithJumps, ComputeFstat):
     F-stat.
     """
 
-    @helper_functions.initializer
+    @utils.initializer
     def __init__(
         self,
         label,
@@ -2366,7 +2328,7 @@ class DeprecatedClass:
     """Outdated classes are marked for future removal by inheriting from this."""
 
     def __new__(cls, *args, **kwargs):
-        logging.warning(
+        logger.warning(
             f"The {cls.__name__} class is no longer maintained"
             " and will be removed in an upcoming release of PyFstat!"
             " If you rely on this class and/or are interested in taking over"
