@@ -12,7 +12,7 @@ import matplotlib.pyplot as plt
 import numpy as np
 from tqdm import tqdm
 
-import pyfstat.helper_functions as helper_functions
+import pyfstat.utils as utils
 from pyfstat.core import (
     BaseSearchClass,
     ComputeFstat,
@@ -21,6 +21,8 @@ from pyfstat.core import (
     SemiCoherentSearch,
 )
 
+logger = logging.getLogger(__name__)
+
 
 class GridSearch(BaseSearchClass):
     """A search evaluating the F-statistic over a regular grid in parameter space.
@@ -67,7 +69,7 @@ class GridSearch(BaseSearchClass):
     fmt_detstat = "%.9g"
     """Standard output precision for detection statistics."""
 
-    @helper_functions.initializer
+    @utils.initializer
     def __init__(
         self,
         label,
@@ -148,7 +150,7 @@ class GridSearch(BaseSearchClass):
             return None
 
     def _initiate_search_object(self):
-        logging.info("Setting up search object")
+        logger.info("Setting up search object")
         search_ranges = self._get_search_ranges()
         if self.nsegs == 1:
             self.search = ComputeFstat(
@@ -204,7 +206,7 @@ class GridSearch(BaseSearchClass):
                 x[0], x[1], num=int((x[1] - x[0]) / x[2]) + 1, endpoint=True
             )
         else:
-            logging.info("Using tuple of length {:d} as is.".format(len(x)))
+            logger.info("Using tuple of length {:d} as is.".format(len(x)))
             return np.array(x)
 
     def _get_input_data_array(self):
@@ -214,7 +216,7 @@ class GridSearch(BaseSearchClass):
         and explicit dtype (cannot have named columns without that).
         (Will also ensure safety when reading/saving data from/to .txt files.)
         """
-        logging.info("Generating input data array")
+        logger.info("Generating input data array")
         coord_arrays = []
         for sl in self.search_keys:
             coord_arrays.append(
@@ -252,13 +254,13 @@ class GridSearch(BaseSearchClass):
            matches in dimension with current grid,
            and the values in those input columns match with the current grid.
 
-        Through `helper_functions.read_txt_file_with_header()`,
+        Through `utils.read_txt_file_with_header()`,
         the existing file is read in with `np.genfromtxt()`.
         """
         if self.clean:
             return False
         if os.path.isfile(self.out_file) is False:
-            logging.info(
+            logger.info(
                 "No old output file '{:s}' found, continuing with grid search.".format(
                     self.out_file
                 )
@@ -269,35 +271,35 @@ class GridSearch(BaseSearchClass):
                 [os.path.getmtime(f) for f in self._get_list_of_matching_sfts()]
             )
             if os.path.getmtime(self.out_file) < oldest_sft:
-                logging.info(
+                logger.info(
                     "Search output data outdates sft files,"
                     + " continuing with grid search."
                 )
                 return False
 
-        logging.info("Checking header of '{:s}'".format(self.out_file))
-        old_params_dict_str_list = (
-            helper_functions.read_parameters_dict_lines_from_file_header(self.out_file)
+        logger.info("Checking header of '{:s}'".format(self.out_file))
+        old_params_dict_str_list = utils.read_parameters_dict_lines_from_file_header(
+            self.out_file
         )
         new_params_dict_str_list = [
             line.strip(" ") for line in self.pprint_init_params_dict()[1:-1]
         ]
         unmatched = np.setxor1d(old_params_dict_str_list, new_params_dict_str_list)
         if len(unmatched) > 0:
-            logging.info(
+            logger.info(
                 "Parameters string in file header does not match"
                 + " current search setup, continuing with grid search."
             )
             return False
         else:
-            logging.info(
+            logger.info(
                 "Parameters string in file header matches current search setup."
             )
 
-        logging.info("Loading old data from '{:s}'.".format(self.out_file))
-        old_data = helper_functions.read_txt_file_with_header(self.out_file, names=True)
+        logger.info("Loading old data from '{:s}'.".format(self.out_file))
+        old_data = utils.read_txt_file_with_header(self.out_file, names=True)
         if len(old_data) != len(self.input_data):
-            logging.info(
+            logger.info(
                 "Old data found in '{:s}', but differs"
                 " in length ({:d} points in file, {:d} points requested);"
                 " continuing with grid search.".format(
@@ -306,7 +308,7 @@ class GridSearch(BaseSearchClass):
             )
             return False
         if len(old_data.dtype) < len(self.input_data.dtype):
-            logging.info(
+            logger.info(
                 "Old data found in '{:s}', but has less columns ({:d})"
                 " than new input parameters grid ({:d});"
                 " continuing with grid search.".format(
@@ -331,7 +333,7 @@ class GridSearch(BaseSearchClass):
             for key in self.search_keys
         ]
         if np.all(column_matches):
-            logging.info(
+            logger.info(
                 "Old data found in '{:s}' with matching input parameters grid,"
                 " no search performed. Data grid size: {:d}x{:d}".format(
                     self.out_file, len(old_data), len(old_data.dtype)
@@ -339,7 +341,7 @@ class GridSearch(BaseSearchClass):
             )
             return old_data
         else:
-            logging.info(
+            logger.info(
                 "Old data found in '{:s}', input parameters grid differs,"
                 "  continuing with grid search.".format(self.out_file)
             )
@@ -376,7 +378,7 @@ class GridSearch(BaseSearchClass):
                 self.data = old_data
                 return
 
-        logging.info(
+        logger.info(
             "Running search over a total of {:d} grid points...".format(
                 np.shape(iterable)[0]
             )
@@ -388,6 +390,7 @@ class GridSearch(BaseSearchClass):
             }
         )
         data = np.zeros(len(self.input_data), dtype=output_dtype)
+
         for n, vals in enumerate(
             tqdm(iterable, total=getattr(self, "total_iterations", None))
         ):
@@ -409,7 +412,7 @@ class GridSearch(BaseSearchClass):
 
     def _get_savetxt_fmt_dict(self):
         """Define the output precision for each parameter and computed quantity."""
-        fmt_dict = helper_functions.get_doppler_params_output_format(self.output_keys)
+        fmt_dict = utils.get_doppler_params_output_format(self.output_keys)
         fmt_dict["twoF"] = self.fmt_detstat
         if self.search.singleFstats:
             for IFO in self.search.detector_names:
@@ -462,7 +465,7 @@ class GridSearch(BaseSearchClass):
         as long as the `_get_savetxt_fmt_dict() method` is suitably overridden
         to account for any additional parameters.
         """
-        logging.info("Saving data to {}".format(self.out_file))
+        logger.info("Saving data to {}".format(self.out_file))
         header = "\n".join(self.output_file_header)
         header += "\n" + " ".join(self.output_keys)
         outfmt = self._get_savetxt_fmt_list()
@@ -781,16 +784,16 @@ class GridSearch(BaseSearchClass):
         i.e. the maximum value and its corresponding parameters.
         """
         d = self.get_max_twoF()
-        print("Grid point with max(twoF) for {}:".format(self.label))
+        logger.info("Grid point with max(twoF) for {}:".format(self.label))
         for k, v in d.items():
-            print("  {}={}".format(k, v))
+            logger.info("  {}={}".format(k, v))
 
     def generate_loudest(self):
         """Use ComputeFstatistic_v2 executable to produce a .loudest file"""
         max_params = self.get_max_twoF()
         max_params.pop("twoF")
         max_params = self.translate_keys_to_lal(max_params)
-        self.loudest_file = helper_functions.generate_loudest_file(
+        self.loudest_file = utils.generate_loudest_file(
             max_params=max_params,
             tref=self.tref,
             outdir=self.outdir,
@@ -885,7 +888,7 @@ class TransientGridSearch(GridSearch):
     only the additional ones are documented here:
     """
 
-    @helper_functions.initializer
+    @utils.initializer
     def __init__(
         self,
         label,
@@ -982,18 +985,18 @@ class TransientGridSearch(GridSearch):
         self.output_file_header = self.get_output_file_header()
         if self.outputTransientFstatMap:
             self.tCWfilebase = os.path.splitext(self.out_file)[0] + "_tCW_"
-            logging.info(
+            logger.info(
                 "Will save per-Doppler Fstatmap"
                 " results to {}*.dat".format(self.tCWfilebase)
             )
 
     def __enter__(self):
-        logging.debug("Entering the TransientGridSearch context...")
+        logger.debug("Entering the TransientGridSearch context...")
         self.search.__enter__()
         return self
 
     def __exit__(self, *args, **kwargs):
-        logging.debug("Leaving the TransientGridSearch context...")
+        logger.debug("Leaving the TransientGridSearch context...")
         self.search.__exit__(*args, **kwargs)
 
     def _set_output_keys(self):
@@ -1001,20 +1004,22 @@ class TransientGridSearch(GridSearch):
         self.output_keys.append("twoF")
         if self.search.singleFstats:
             self.output_keys += [f"twoF{IFO}" for IFO in self.search.detector_names]
-        self.output_keys.append("maxTwoF")
+        if self.transientWindowType:
+            self.output_keys.append("maxTwoF")
         if hasattr(self.search, "twoFXatMaxTwoF"):
             self.output_keys += [
                 f"twoF{IFO}atMaxTwoF" for IFO in self.search.detector_names
             ]
         if self.detstat != "maxTwoF":
             self.output_keys.append(self.detstat)
-        # for consistency below, t0/tau must come after detstat
-        # they are not included in self.search_keys because the main Fstat
-        # code does not loop over them
-        self.output_keys += ["t0", "tau"]
+        if self.transientWindowType:
+            # for consistency below, t0/tau must come after detstat
+            # they are not included in self.search_keys because the main Fstat
+            # code does not loop over them
+            self.output_keys += ["t0", "tau"]
 
     def _initiate_search_object(self):
-        logging.info("Setting up search object")
+        logger.info("Setting up search object")
         search_ranges = self._get_search_ranges()
         self.search = ComputeFstat(
             tref=self.tref,
@@ -1085,7 +1090,7 @@ class TransientGridSearch(GridSearch):
         )
         data = np.zeros(len(self.input_data), dtype=output_dtype)
         self.timingFstatMap = 0.0
-        logging.info(
+        logger.info(
             "Running search over a total of {:d} grid points...".format(
                 np.shape(self.input_data)[0]
             )
@@ -1098,7 +1103,8 @@ class TransientGridSearch(GridSearch):
             thisCand.append(self.search.twoF)
             if self.search.singleFstats:
                 thisCand += list(self.search.twoFX[: self.search.numDetectors])
-            thisCand.append(self.search.maxTwoF)
+            if hasattr(self.search, "maxTwoF"):
+                thisCand.append(self.search.maxTwoF)
             if hasattr(self.search, "twoFXatMaxTwoF"):
                 thisCand += list(self.search.twoFXatMaxTwoF[: self.search.numDetectors])
             if self.detstat != "maxTwoF":
@@ -1123,7 +1129,7 @@ class TransientGridSearch(GridSearch):
             if self.outputAtoms:
                 self.search.write_atoms_to_file(os.path.splitext(self.out_file)[0])
 
-        logging.info(
+        logger.info(
             "Total time spent computing transient F-stat maps: {:.2f}s".format(
                 self.timingFstatMap
             )
@@ -1165,7 +1171,7 @@ class TransientGridSearch(GridSearch):
 
     def _get_savetxt_fmt_dict(self):
         """Define the output precision for each parameter and computed quantity."""
-        fmt_dict = helper_functions.get_doppler_params_output_format(self.output_keys)
+        fmt_dict = utils.get_doppler_params_output_format(self.output_keys)
         fmt_dict["twoF"] = self.fmt_detstat
         if self.search.singleFstats:
             for IFO in self.search.detector_names:
@@ -1200,7 +1206,7 @@ class GridGlitchSearch(GridSearch):
     This class currently only works for a single glitch in the observing time.
     """
 
-    @helper_functions.initializer
+    @utils.initializer
     def __init__(
         self,
         label,
@@ -1268,7 +1274,7 @@ class GridGlitchSearch(GridSearch):
         self.output_file_header = self.get_output_file_header()
 
     def _initiate_search_object(self):
-        logging.info("Setting up search object")
+        logger.info("Setting up search object")
         search_ranges = self._get_search_ranges()
         self.search = SemiCoherentGlitchSearch(
             label=self.label,
@@ -1287,7 +1293,7 @@ class GridGlitchSearch(GridSearch):
 
     def _get_savetxt_fmt_dict(self):
         """Define the output precision for each parameter and computed quantity."""
-        fmt_dict = helper_functions.get_doppler_params_output_format(self.output_keys)
+        fmt_dict = utils.get_doppler_params_output_format(self.output_keys)
         fmt_dict["delta_F0"] = "%.16g"
         fmt_dict["delta_F1"] = "%.16g"
         fmt_dict["tglitch"] = "%d"
