@@ -6,7 +6,9 @@ import lalpulsar
 import numpy as np
 from attrs import define, field
 
-from pyfstat.helper_functions import get_ephemeris_files
+from pyfstat.utils import convert_h0_cosi_to_aPlus_aCross, get_ephemeris_files
+
+logger = logging.getLogger(__name__)
 
 
 @define(kw_only=True, slots=False)
@@ -298,9 +300,7 @@ class SignalToNoiseRatio:
             raise ValueError("Need either (h0, cosi) or (aPlus, aCross), but not both")
 
         if h0_cosi:
-            aPlus = 0.5 * h0 * (1 + cosi**2)
-            aCross = h0 * cosi
-            return aPlus, aCross
+            aPlus, aCross = convert_h0_cosi_to_aPlus_aCross(h0, cosi)
 
         return aPlus, aCross
 
@@ -440,16 +440,16 @@ class DetectorStates:
                         "no comma-separated strings allowed."
                     )
 
-            logging.debug("Retrieving detectors from timestamps dictionary.")
+            logger.debug("Retrieving detectors from timestamps dictionary.")
             detectors = list(timestamps.keys())
-            timestamps = timestamps.values()
+            timestamps = (np.array(ts) for ts in timestamps.values())
 
         elif detectors is not None:
             if isinstance(detectors, str):
-                logging.debug("Converting `detectors` string to list")
+                logger.debug("Converting `detectors` string to list")
                 detectors = detectors.replace(" ", "").split(",")
 
-            logging.debug("Checking integrity of `timestamps`")
+            logger.debug("Checking integrity of `timestamps`")
             ts = np.array(timestamps)
             if ts.dtype == np.dtype("O") or ts.ndim > 1:
                 raise ValueError("`timestamps` is not a 1D list of numerical values")
