@@ -24,11 +24,11 @@ class TestReadParFile(BaseForTestsWithOutdir):
         parfile = os.path.join(self.outdir, self.label + ".par")
         os.system('echo "x=100\ny=10" > ' + parfile)
 
-        par = pyfstat.helper_functions.read_par(filename=parfile)
+        par = pyfstat.utils.read_par(filename=parfile)
         self.assertTrue(par["x"] == 100)
         self.assertTrue(par["y"] == 10)
 
-        par = pyfstat.helper_functions.read_par(outdir=self.outdir, label=self.label)
+        par = pyfstat.utils.read_par(outdir=self.outdir, label=self.label)
         self.assertTrue(par["x"] == 100)
         self.assertTrue(par["y"] == 10)
 
@@ -39,7 +39,7 @@ class TestPredictFstat(BaseForTestsWithOutdir):
     # which itself is tested through the Writer and Search classes
 
     def test_PFS_noise(self):
-        twoF_expected, twoF_sigma = pyfstat.helper_functions.predict_fstat(
+        twoF_expected, twoF_sigma = pyfstat.utils.predict_fstat(
             minStartTime=default_Writer_params["tstart"],
             duration=default_Writer_params["duration"],
             IFOs=default_Writer_params["detectors"],
@@ -65,7 +65,7 @@ class TestPredictFstat(BaseForTestsWithOutdir):
                         default_Writer_params["tstart"] + default_Writer_params["Tsft"],
                     )
                 )
-        twoF_expected, twoF_sigma = pyfstat.helper_functions.predict_fstat(
+        twoF_expected, twoF_sigma = pyfstat.utils.predict_fstat(
             timestampsFiles=",".join(TSfiles),
             IFOs=",".join(IFOs),
             assumeSqrtSX=1,
@@ -78,7 +78,7 @@ class TestPredictFstat(BaseForTestsWithOutdir):
 
     def test_PFS_signal(self):
         duration = 10 * default_Writer_params["duration"]
-        twoF_expected, twoF_sigma = pyfstat.helper_functions.predict_fstat(
+        twoF_expected, twoF_sigma = pyfstat.utils.predict_fstat(
             h0=1,
             cosi=0,
             psi=0,
@@ -102,8 +102,8 @@ class TestPredictFstat(BaseForTestsWithOutdir):
             "F0": 0,
             "F1": 0,
         }
-        params = pyfstat.helper_functions.get_predict_fstat_parameters_from_dict(params)
-        twoF_expected_dict, twoF_sigma_dict = pyfstat.helper_functions.predict_fstat(
+        params = pyfstat.utils.get_predict_fstat_parameters_from_dict(params)
+        twoF_expected_dict, twoF_sigma_dict = pyfstat.utils.predict_fstat(
             **params,
             minStartTime=default_Writer_params["tstart"],
             duration=duration,
@@ -119,11 +119,8 @@ class TestPredictFstat(BaseForTestsWithOutdir):
         params["transientWindowType"] = "rect"
         params["transient_tstart"] = default_Writer_params["tstart"]
         params["transient_duration"] = 0.5 * duration
-        params = pyfstat.helper_functions.get_predict_fstat_parameters_from_dict(params)
-        (
-            twoF_expected_transient,
-            twoF_sigma_transient,
-        ) = pyfstat.helper_functions.predict_fstat(
+        params = pyfstat.utils.get_predict_fstat_parameters_from_dict(params)
+        (twoF_expected_transient, twoF_sigma_transient,) = pyfstat.utils.predict_fstat(
             **params,
             minStartTime=default_Writer_params["tstart"],
             duration=duration,
@@ -625,11 +622,10 @@ class TestComputeFstat(BaseForTestsWithData):
         self.assertTrue(reldiffend < 0.25)
 
 
-@pytest.mark.parametrize("tCWFstatMapVersion", ["lal", "pycuda"])
-@pytest.mark.parametrize("transientWindowType", [None, "rect"])
-@pytest.mark.parametrize("cleanup", ["no", "manual", "contextmanager"])
-def test_context_finalizer(tCWFstatMapVersion, transientWindowType, cleanup):
-    CFS_params = {
+@pytest.fixture
+def CFS_default_params():
+    # FIXME: `default_Writer_params` should be yet another fixture
+    return {
         "tref": default_Writer_params["tstart"],
         "minStartTime": default_Writer_params["tstart"],
         "maxStartTime": default_Writer_params["tstart"]
@@ -639,7 +635,11 @@ def test_context_finalizer(tCWFstatMapVersion, transientWindowType, cleanup):
         "minCoverFreq": default_signal_params["F0"] - 0.1,
         "maxCoverFreq": default_signal_params["F0"] + 0.1,
     }
-    lambda_params = {
+
+
+@pytest.fixture
+def lambda_params():
+    return {
         "F0": default_signal_params["F0"],
         "F1": default_signal_params["F1"],
         "F2": default_signal_params["F2"],
@@ -647,40 +647,44 @@ def test_context_finalizer(tCWFstatMapVersion, transientWindowType, cleanup):
         "Delta": default_signal_params["Delta"],
     }
 
-    if "cuda" not in tCWFstatMapVersion:
-        search = pyfstat.ComputeFstat(
-            **CFS_params,
-            tCWFstatMapVersion="lal",
-        )
-        assert search._finalizer is None
-        return
+
+@pytest.mark.parametrize("tCWFstatMapVersion", ["lal", "pycuda"])
+@pytest.mark.parametrize("transientWindowType", [None, "rect"])
+@pytest.mark.parametrize("cleanup", ["no", "manual", "contextmanager"])
+def test_context_finalizer(
+    CFS_default_params, lambda_params, tCWFstatMapVersion, transientWindowType, cleanup
+):
+    if cleanup == "manual" and not tCWFstatMapVersion == "pycuda":
+        pytest.skip("Manual cleanup won't work in non-pycuda case.")
 
     # if GPU available, try the real thing;
     # else this should still set up the finalizer
     # but without actually trying to run on GPU
-    have_pycuda = pyfstat.tcw_fstat_map_funcs._optional_imports_pycuda()
-    if have_pycuda:
-        if cleanup == "no":
+    if tCWFstatMapVersion == "pycuda":
+        have_pycuda = pyfstat.tcw_fstat_map_funcs._optional_imports_pycuda()
+        if not have_pycuda:
+            pytest.skip("Optional imports failed, skipping actual pycuda test.")
+        elif cleanup == "no":
             pytest.skip("This case might work but will sabotage others.")
-    else:
-        pytest.skip("Optional imports failed, skipping actual pycuda test.")
     if cleanup == "contextmanager":
         with pyfstat.ComputeFstat(
-            **CFS_params,
+            **CFS_default_params,
             tCWFstatMapVersion=tCWFstatMapVersion,
             transientWindowType=transientWindowType,
         ) as search:
-            assert search._finalizer is not None
-            assert search._finalizer.alive
+            if tCWFstatMapVersion == "pycuda":
+                assert search._finalizer is not None
+                assert search._finalizer.alive
             detstat = search.get_fullycoherent_detstat(**lambda_params)
     else:
         search = pyfstat.ComputeFstat(
-            **CFS_params,
+            **CFS_default_params,
             tCWFstatMapVersion=tCWFstatMapVersion,
             transientWindowType=transientWindowType,
         )
-        assert search._finalizer is not None
-        assert search._finalizer.alive
+        if tCWFstatMapVersion == "pycuda":
+            assert search._finalizer is not None
+            assert search._finalizer.alive
         detstat = search.get_fullycoherent_detstat(**lambda_params)
         if cleanup == "manual":
             # calling finalizer manually should kill it
@@ -689,6 +693,34 @@ def test_context_finalizer(tCWFstatMapVersion, transientWindowType, cleanup):
     assert detstat > 0
 
 
+def test_atoms_io(tmp_path, CFS_default_params, lambda_params):
+    search = pyfstat.ComputeFstat(
+        **CFS_default_params,
+        computeAtoms=True,
+    )
+    search.get_fullycoherent_detstat(**lambda_params)
+    atoms_orig = pyfstat.tcw_fstat_map_funcs.reshape_FstatAtomsVector(
+        search.FstatResults.multiFatoms[0].data[0]
+    )
+    atomsdir = tmp_path
+    search.write_atoms_to_file(atomsdir / "CFS")
+    atomsfiles = [(atomsdir / f) for f in os.listdir(atomsdir) if "Fstatatoms" in f]
+    assert len(atomsfiles) == 1
+    atoms_read = pyfstat.utils.read_txt_file_with_header(atomsfiles[0], comments="%%")
+    assert len(atoms_read.dtype.names) == 8
+    assert len(atoms_read) == len(atoms_orig["timestamp"])
+    for key_read in atoms_read.dtype.names:
+        if key_read == "tGPS":
+            key_orig = "timestamp"
+        elif "_" in key_read:
+            key_orig = key_read.replace("_", "_alpha_")
+        else:
+            key_orig = key_read + "_alpha"
+        assert np.allclose(
+            atoms_read[key_read], atoms_orig[key_orig], rtol=1e-6, atol=1e-6
+        )
+
+
 class TestComputeFstatNoNoise(BaseForTestsWithData):
     # FIXME: should be possible to merge into TestComputeFstat with smart
     # defaults handlingf
@@ -722,7 +754,7 @@ class TestComputeFstatNoNoise(BaseForTestsWithData):
         (
             earth_ephem_default,
             sun_ephem_default,
-        ) = pyfstat.helper_functions.get_ephemeris_files()
+        ) = pyfstat.utils.get_ephemeris_files()
 
         search = pyfstat.ComputeFstat(
             tref=self.Writer.tref,
