@@ -19,6 +19,86 @@ from commons_for_tests import (
 import pyfstat
 
 
+def test_timestamp_files(tmp_path, caplog):
+
+    Tsft = 1800
+    single_column = 10000000 + Tsft * np.arange(10)
+    np.savetxt(tmp_path / "single_column.txt", single_column[:, None])
+
+    writer = pyfstat.Writer(
+        outdir=str(tmp_path / "timestamp_file_testing"),
+        label="timestamp_file_testing",
+        F0=10,
+        Band=0.1,
+        detectors="H1",
+        sqrtSX=1e-23,
+        Tsft=Tsft,
+        timestamps=str(tmp_path / "single_column.txt"),
+    )
+
+    assert single_column[0] == writer.tstart
+    assert single_column[-1] - single_column[0] == writer.duration - Tsft
+
+    np.savetxt(tmp_path / "dual_column.txt", np.hstack(2 * [single_column[:, None]]))
+    with caplog.at_level("WARNING"):
+        writer = pyfstat.Writer(
+            outdir=str(tmp_path / "timestamp_file_testing"),
+            label="timestamp_file_testing",
+            F0=10,
+            Band=0.1,
+            detectors="H1",
+            sqrtSX=1e-23,
+            Tsft=Tsft,
+            timestamps=str(tmp_path / "dual_column.txt"),
+        )
+
+        _, _, log_message = caplog.record_tuples[-1]
+        assert "has more than 1 column" in log_message
+        assert "will ignore" in log_message
+
+    np.savetxt(tmp_path / "float_column.txt", 0.01 + single_column[:, None])
+    with caplog.at_level("WARNING"):
+        writer = pyfstat.Writer(
+            outdir=str(tmp_path / "timestamp_file_testing"),
+            label="timestamp_file_testing",
+            F0=10,
+            Band=0.1,
+            detectors="H1",
+            sqrtSX=1e-23,
+            Tsft=Tsft,
+            timestamps=str(tmp_path / "float_column.txt"),
+        )
+
+        _, _, log_message = caplog.record_tuples[-1]
+        assert "non-integer timestamps" in log_message
+        assert "floor" in log_message
+
+    # Test wrong number of detectors
+    with pytest.raises(ValueError):
+
+        writer = pyfstat.Writer(
+            outdir=str(tmp_path / "timestamp_file_testing"),
+            label="timestamp_file_testing",
+            F0=10,
+            Band=0.1,
+            detectors="H1,L1",
+            sqrtSX=1e-23,
+            timestamps=str(tmp_path / "single_column.txt"),
+        )
+
+    # Test unspecified detectors
+    with pytest.raises(ValueError):
+
+        writer = pyfstat.Writer(
+            outdir=str(tmp_path / "timestamp_file_testing"),
+            label="timestamp_file_testing",
+            F0=10,
+            Band=0.1,
+            sqrtSX=1e-23,
+            timestamps=str(tmp_path / "single_column.txt"),
+        )
+
+
 class TestWriter(BaseForTestsWithData):
     label = "TestWriter"
     writer_class_to_test = pyfstat.Writer
@@ -145,11 +225,9 @@ class TestWriter(BaseForTestsWithData):
             noise_and_signal_freqs,
             times,
             noise_and_signal_data,
-        ) = pyfstat.helper_functions.get_sft_as_arrays(
-            noise_and_signal_writer.sftfilepath
-        )
+        ) = pyfstat.utils.get_sft_as_arrays(noise_and_signal_writer.sftfilepath)
 
-        noise_freqs, _, noise_data = pyfstat.helper_functions.get_sft_as_arrays(
+        noise_freqs, _, noise_data = pyfstat.utils.get_sft_as_arrays(
             noise_writer.sftfilepath
         )
 
@@ -157,9 +235,9 @@ class TestWriter(BaseForTestsWithData):
             add_signal_freqs,
             _,
             add_signal_data,
-        ) = pyfstat.helper_functions.get_sft_as_arrays(add_signal_writer.sftfilepath)
+        ) = pyfstat.utils.get_sft_as_arrays(add_signal_writer.sftfilepath)
 
-        constr_freqs, _, constr_data = pyfstat.helper_functions.get_sft_as_arrays(
+        constr_freqs, _, constr_data = pyfstat.utils.get_sft_as_arrays(
             add_signal_writer_constr.sftfilepath
         )
 
@@ -307,13 +385,13 @@ class TestWriter(BaseForTestsWithData):
         )
         writer.make_data(verbose=True)
         # split them by frequency
-        cl_split = pyfstat.helper_functions.get_lal_exec("splitSFTs")
+        cl_split = pyfstat.utils.get_lal_exec("splitSFTs")
         cl_split += " --frequency-bandwidth 1"
         cl_split += f" --start-frequency {writer.fmin}"
         cl_split += f" --end-frequency {writer.fmin+writer.Band}"
         cl_split += f" --output-directory {self.outdir}"
         cl_split += f" -- {writer.sftfilepath}"
-        pyfstat.helper_functions.run_commandline(cl_split)
+        pyfstat.utils.run_commandline(cl_split)
         # reuse the split SFTs as noiseSFTs
         NB_recycling_writer = self.writer_class_to_test(
             label="test_noiseSFTs_recycle",
@@ -328,10 +406,22 @@ class TestWriter(BaseForTestsWithData):
         )
         NB_recycling_writer.make_data(verbose=True)
 
-    def _test_writer_with_tsfiles(self, gaps=False):
-        """helper function to rerun with/without gaps"""
+    def _test_writer_with_tsfiles(self, gaps=False, nanoseconds=False):
+        """helper function for timestamps tests
+
+        Can be used to rerun timestamps tests with/without gaps,
+        and with new single-column (nanoseconds=False)
+        and old two-column (nanoseconds=True)
+        formats.
+        """
         IFOs = self.multi_detectors.split(",")
-        tsfiles = [os.path.join(self.outdir, f"timestamps_{IFO}.txt") for IFO in IFOs]
+        tsfiles = [
+            os.path.join(
+                self.outdir,
+                f"timestamps_{IFO}{'_gaps' if gaps else ''}{'_ns' if nanoseconds else ''}.txt",
+            )
+            for IFO in IFOs
+        ]
         numSFTs = []
         for X, tsfile in enumerate(tsfiles):
             with open(tsfile, "w") as fp:
@@ -340,7 +430,8 @@ class TestWriter(BaseForTestsWithData):
                     if (
                         not gaps or not k == X + 1
                     ):  # add gaps at different points for each IFO
-                        fp.write(f"{self.tstart + k*self.Tsft} 0\n")
+                        line = f"{self.tstart + k*self.Tsft}{' 0' if nanoseconds else ''}\n"
+                        fp.write(line)
                     k += 1
             if gaps:
                 numSFTs.append(k - 1)
@@ -387,8 +478,9 @@ class TestWriter(BaseForTestsWithData):
             )
 
     def test_timestamps(self):
-        self._test_writer_with_tsfiles(gaps=False)
-        self._test_writer_with_tsfiles(gaps=True)
+        for gaps in [False, True]:
+            for nanoseconds in [False, True]:
+                self._test_writer_with_tsfiles(gaps, nanoseconds)
 
     def test_timestamps_file_generation(self):
 
@@ -419,7 +511,6 @@ class TestWriter(BaseForTestsWithData):
             )
             self.assertTrue(os.path.isfile(timestamps_file))
             ts = np.genfromtxt(timestamps_file)
-            ts = ts[:, 0] + 1e-9 * ts[:, 1]
             np.testing.assert_almost_equal(ts, timestamps[ifo])
 
         # Test dictionary with input detector
@@ -451,7 +542,6 @@ class TestWriter(BaseForTestsWithData):
             )
             self.assertTrue(os.path.isfile(timestamps_file))
             ts = np.genfromtxt(timestamps_file)
-            ts = ts[:, 0] + 1e-9 * ts[:, 1]
             np.testing.assert_almost_equal(ts, timestamps[ifo])
 
         # Test single list
@@ -481,7 +571,6 @@ class TestWriter(BaseForTestsWithData):
             )
             self.assertTrue(os.path.isfile(timestamps_file))
             ts = np.genfromtxt(timestamps_file)
-            ts = ts[:, 0] + 1e-9 * ts[:, 1]
             np.testing.assert_almost_equal(ts, timestamps)
 
 
@@ -531,9 +620,7 @@ class TestLineWriter(TestWriter):
         self.assertFalse(first_time == third_time)
 
     def _check_maximum_power_consistency(self, writer):
-        freqs, times, data = pyfstat.helper_functions.get_sft_as_arrays(
-            writer.sftfilepath
-        )
+        freqs, times, data = pyfstat.utils.get_sft_as_arrays(writer.sftfilepath)
         for ifo in times.keys():
             max_power_freq_index = np.argmax(np.abs(data[ifo]), axis=0)
             line_active_mask = (writer.transientStartTime <= times[ifo]) & (
@@ -686,17 +773,17 @@ class TestGlitchWriter(TestWriter):
             freqs_vanilla,
             times_vanilla,
             data_vanilla,
-        ) = pyfstat.helper_functions.get_sft_as_arrays(vanillaWriter.sftfilepath)
+        ) = pyfstat.utils.get_sft_as_arrays(vanillaWriter.sftfilepath)
         (
             freqs_noglitch,
             times_noglitch,
             data_noglitch,
-        ) = pyfstat.helper_functions.get_sft_as_arrays(noGlitchWriter.sftfilepath)
+        ) = pyfstat.utils.get_sft_as_arrays(noGlitchWriter.sftfilepath)
         (
             freqs_glitch,
             times_glitch,
             data_glitch,
-        ) = pyfstat.helper_functions.get_sft_as_arrays(glitchWriter.sftfilepath)
+        ) = pyfstat.utils.get_sft_as_arrays(glitchWriter.sftfilepath)
 
         for ifo in self.detectors.split(","):
             max_freq_vanilla = freqs_vanilla[
